This project is not ready to be used or reliable yet. I'll continue to update this as I make progress.

The aim is to have the swarm be able to build entire software projects, doing iterative development, testing and deployment, while talking to the user to clarify intent and understand requirements. Essentially trying to automate knowledge work.

Documentation:
https://brianp8701.github.io/swarmstar/

Building web app interface to use swarmstar:
https://github.com/BrianP8701/swarmstar_interface


[AI Agent Swarm Playlist](https://youtube.com/playlist?list=PLO8gVow6df_Rh7DEJ10_WAdnkGnIRCh-K&si=eYdyBu7NShKckilS)
